@@ -29,7 +29,12 @@ def Get_database():
         return dict(CONFIG['DATABASE'])
     else:
         raise Exception('DATABASE not in CONFIG!')
-        
+
+def Get_repeater():
+    if 'REPEATER' in CONFIG:
+        return dict(CONFIG['REPEATER'])
+    else:
+        raise Exception('REPEATER not in CONFIG!')
     # DICTIONARY = set()
     # if 'DICTIONARY' in CONFIG['DEFAULT']:
     #     DICTIONARY = set(readlist(os.path.join(os.path.dirname(__file__), CONFIG['DEFAULT']['DICTIONARY'])))
